@@ -580,7 +580,13 @@ glance.ETS <- function(x, ...) {
 #'   tidy()
 #' @export
 tidy.ETS <- function(x, ...) {
-  x$par
+  length(measured_vars(x$states))
+  init <- initial_ets_states(x)
+  n_coef <- nrow(x$par) - (ncol(init)-(x$spec$seasontype!="N"))
+  dplyr::bind_rows(
+    x$par[seq_len(n_coef),],
+    tidyr::pivot_longer(init, seq_along(init), names_to = "term", values_to = "estimate")
+  )
 }
 
 #' Extract estimated states from an ETS model.
@@ -687,7 +693,7 @@ report.ETS <- function(object, ...) {
   }
 
   cat("\n  Initial states:\n")
-  print.data.frame(object$states[1, measured_vars(object$states)], row.names = FALSE)
+  print.data.frame(initial_ets_states(object), row.names = FALSE)
 
   cat("\n  sigma^2:  ")
   cat(round(object$fit$sigma2, 4))
@@ -697,3 +703,14 @@ report.ETS <- function(object, ...) {
     print(stats)
   }
 }
+
+initial_ets_states <- function(object) {
+  states_init <- object$states[1, measured_vars(object$states)]
+  states_type <- substring(colnames(states_init), 1, 1)
+  states_names <- lapply(
+    split(states_type, states_type),
+    function(x) paste0(x, "[", seq(0, by = -1, along = x), "]")
+  )
+  colnames(states_init) <- unsplit(states_names, states_type)
+  states_init
+}
\ No newline at end of file
