@@ -120,7 +120,6 @@ forecast.model_mean <- function(object, new_data, specials = NULL, bootstrap = F
     }) %>%
       transpose() %>%
       map(as.numeric)
-    se <- map_dbl(sim, stats::sd)
     distributional::dist_sample(sim)
   } else {
     fc <- rep(y_mean, h)
@@ -154,9 +153,7 @@ generate.model_mean <- function(x, new_data, bootstrap = FALSE, ...) {
     }
   }
 
-  new_data %>%
-    group_by_key() %>%
-    transmute(".sim" := f + !!sym(".innov"))
+  transmute(group_by_key(new_data), ".sim" := f + !!sym(".innov"))
 }
 
 #' @inherit interpolate.ARIMA
@@ -259,3 +256,54 @@ report.model_mean <- function(object, ...) {
 model_sum.model_mean <- function(x) {
   paste0("MEAN") # , ", intToUtf8(0x3BC), "=", format(x$par$estimate))
 }
+
+#' Refit a MEAN model
+#'
+#' Applies a fitted average method model to a new dataset.
+#'
+#' @inheritParams refit.ARIMA
+#' @param reestimate If `TRUE`, the mean for the fitted model will be re-estimated 
+#' to suit the new data. 
+#' 
+#' @examples
+#' lung_deaths_male <- as_tsibble(mdeaths)
+#' lung_deaths_female <- as_tsibble(fdeaths)
+#'
+#' fit <- lung_deaths_male %>%
+#'   model(MEAN(value))
+#'
+#' report(fit)
+#'
+#' fit %>%
+#'   refit(lung_deaths_female) %>%
+#'   report()
+#' @export
+refit.model_mean <- function(object, new_data, specials = NULL, reestimate = FALSE, ...) {
+  # Update data for re-evaluation
+  # update specials
+  specials$window <- if(is.na(object$window)) NULL else object$window 
+
+  if (reestimate) {
+    return(train_mean(new_data, specials, ...))
+  }
+  
+  y <- unclass(new_data)[[measured_vars(new_data)]]
+  
+  if (all(is.na(y))) {
+    abort("All new observations are missing, model cannot be applied.")
+  }
+
+  if (!is_null(specials$window)) warn("A rolling mean model cannot be refitted, the most recent mean from the fitted model will be used as a fixed estimate of the mean.")
+  
+  n <- length(y)
+
+  fits <- rep(object$mean, n)
+  res <- y - fits
+  sigma <- sd(res, na.rm = TRUE)
+  
+  object$fitted <- fits
+  object$resid <- res
+  object$sigma <- sigma
+  object$nobs <- sum(!is.na(y))
+  object
+}
