@@ -317,13 +317,14 @@ tidy.VAR <- function(x) {
   R <- chol2inv(x$model$qr$qr[seq_len(rank), seq_len(rank), drop = FALSE])
   se <- map(resvar, function(resvar) sqrt(diag(R) * resvar))
 
-  dplyr::as_tibble(x$coef, rownames = "term") %>%
-    tidyr::gather(".response", "estimate", !!!syms(colnames(x$coef))) %>%
-    mutate(
-      std.error = unlist(se),
-      statistic = !!sym("estimate") / !!sym("std.error"),
-      p.value = 2 * stats::pt(abs(!!sym("statistic")), rdf, lower.tail = FALSE)
-    )
+  coef <- dplyr::as_tibble(x$coef, rownames = "term")
+  coef <- tidyr::gather(coef, ".response", "estimate", !!!syms(colnames(x$coef)))
+  mutate(
+    coef,
+    std.error = unlist(se),
+    statistic = !!sym("estimate") / !!sym("std.error"),
+    p.value = 2 * stats::pt(abs(!!sym("statistic")), rdf, lower.tail = FALSE)
+  )
 }
 
 
